@@ -6,14 +6,12 @@ import logging
 
 import time
 
-
 import socketio
 import ubjson
 import ujson as ujson
 from multiprocessing.dummy import Pool
 
 
-
 class GSCNodeFunctionReceiverSocket:
     @classmethod
     def create(cls, sio, gsdbs, oncnodefunction, poolsize):
@@ -34,7 +32,7 @@ class GSCNodeFunctionReceiverSocket:
             # self._logger.info('cnodefunction succeed')
 
         def on_errorPost(error):
-            self._logger.exception('cnodefunction failed :' + error)
+            self._logger.exception('cnodefunction failed : ' + str(error))
 
         @self.sio.event
         def oncnodefunction(id, msg):
